src/hbcore/utils/hbwidgetloader.cpp
changeset 7 923ff622b8b9
parent 5 627c4a0fd0e7
child 21 4633027730f5
child 34 ed14f46c0e55
--- a/src/hbcore/utils/hbwidgetloader.cpp	Wed Jun 23 18:33:25 2010 +0300
+++ b/src/hbcore/utils/hbwidgetloader.cpp	Tue Jul 06 14:36:53 2010 +0300
@@ -56,7 +56,7 @@
 
 #define hbInstance (HbInstance::instance())
 
 // cache at the client side to store the mesh items.
 // key used here is the filename+layoutname+sectionname.
 
 typedef QHash<QString,HbWidgetLoader::LayoutDefinition*> ClientHashForLayoutDefs;
@@ -146,14 +146,14 @@
 /*!
     Loads and processes a WidgetML file.
 
-    If the widget already has a layout assumes it's HbMeshLayout.
-    If the widget doesn't have a layout creates HbMeshLayout and sets it to widget.
+    If the widget already has a layout assumes it's HbAnchorLayout.
+    If the widget doesn't have a layout creates HbAnchorLayout and sets it to widget.
     Creates the anchor edge attachments based on WidgetML.
 
     \param fileName file to be processed.
     \param name the name of the layout to be loaded.
     \param section space separated route to section, that you want to load.
-    \param storage specifies where to store the mesh items.
+    \param storage specifies where to store the anchor items.
     \return true if file was loaded and processed successfully.
 */
 bool HbWidgetLoader::load(
@@ -268,7 +268,7 @@
     const QString &section,
     HbWidgetLoader::LayoutDefinition *&layoutDef )
 {
     // check in the client side cache if the vector of meshitems is present.
     QString key (fileName + name + section);
     if (clientLayoutDefsCache()->contains(key)){
         // present in the client cache.
@@ -56,7 +56,7 @@
 #define hbInstance (HbInstance::instance())
 
-// cache at the client side to store the mesh items.
+// cache at the client side to store the anchor items.
 // key used here is the filename+layoutname+sectionname.
 
@@ -268,7 +268,7 @@
     HbWidgetLoader::LayoutDefinition *&layoutDef )
 {
-    // check in the client side cache if the vector of meshitems is present.
+    // check in the client side cache if the vector of anchor items is present.
     QString key (fileName + name + section);
     if (clientLayoutDefsCache()->contains(key)){